/***************************************************************************
 *   Copyright (C) 2005 by Siraj Razick                                    *
 *   sirajr@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "kbfxcfgdialog.h"
#include <kfiledialog.h>
#include <kpushbutton.h>
#include <qlineedit.h>
#include <qimage.h>
#include <qiconset.h>
#include <qlabel.h>
#include <qcheckbox.h>
#include <qapplication.h>
#include <kiconloader.h>
#include <kurlrequester.h>
#include "settings.h"


KbfxCfgDialog::KbfxCfgDialog(QWidget *parent, const char *name)
    :KbfxConfigDialogWidget(parent, name)
{
    // load clear_left icon
    QIconSet icon = SmallIcon( QApplication::reverseLayout() ? "clear_left" : "locationbar_erase" );
    
    //this->clearButton->setIconSet( icon );
    this->btnResetNormal->setIconSet( icon );
    this->btnResetPressed->setIconSet( icon );
    this->btnResetHover->setIconSet( icon );
 
   QString pixmapStr;
   
   pixmapStr = KbfxCfg::normal();
   
   if (pixmapStr) {            
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixNormal->setPixmap( pixmap );
   }
   
   pixmapStr = KbfxCfg::hover();
   
   if (pixmapStr) {            
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixHover->setPixmap( pixmap );
   }
   
   pixmapStr = KbfxCfg::pressed();
   
   if (pixmapStr) {            
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixPressed->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::btnResetPressed_clicked()
{
   QString pixmapStr;
   pixmapStr = KbfxCfg::pressed();
   
   if (pixmapStr) {            
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixPressed->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::btnResetNormal_clicked()
{
   QString pixmapStr;
   pixmapStr = KbfxCfg::normal();
   
   this->kcfg_Normal->setURL( pixmapStr );
   
   if (pixmapStr) {            
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixNormal->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::kcfg_Normal_urlSelected(const QString& pixmapStr)
{
   if (pixmapStr) {
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixNormal->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::btnResetHover_clicked()
{
   QString pixmapStr;
   pixmapStr = KbfxCfg::hover();
   
   if (pixmapStr) {            
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixHover->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::kcfg_Hover_urlSelected(const QString& pixmapStr)
{
   if (pixmapStr) {
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixHover->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::kcfg_Pressed_urlSelected(const QString& pixmapStr)
{
   if (pixmapStr) {
      // set image
      QImage pixmap = QImage( pixmapStr );
      //if (pixmap.isNull)
         this->pixPressed->setPixmap( pixmap );
   }
}

void KbfxCfgDialog::loadConfig( )
{
    // normal
    this->kcfg_Normal->setURL(KbfxCfg::normal());
    
    // pressed
    this->kcfg_Pressed->setURL(KbfxCfg::pressed());
    
    // hover
    this->kcfg_Hover->setURL(KbfxCfg::hover());
    
    // enable glow
    this->kcfg_EnableGlow->setChecked(KbfxCfg::enableGlow());
    
    // auto adjust kicker
    this->kcfg_AutoAdjustKicker->setChecked(KbfxCfg::autoAdjustKicker());
    
    // tooltip
    this->kcfg_Tooltips->setText(KbfxCfg::tooltips());
}

void KbfxCfgDialog::saveConfig( )
{
    KbfxCfg::setNormal( this->kcfg_Normal->url() );
    KbfxCfg::setPressed( this->kcfg_Pressed->url() );
    KbfxCfg::setHover( this->kcfg_Hover->url() );
    
    KbfxCfg::setEnableGlow( this->kcfg_EnableGlow->isChecked() );
    KbfxCfg::setAutoAdjustKicker( this->kcfg_AutoAdjustKicker->isChecked() );
    
    KbfxCfg::setTooltips( this->kcfg_Tooltips->text() );
    
    KbfxCfg::writeConfig();
}

#include "kbfxcfgdialog.moc"
